package com.qianhe.mapper;

import java.util.List;
import com.qianhe.domain.BzscYsjglggzscfj;
import com.qianhe.domain.WdWdxxRd;

/**
 * 标准手册-油水井管理岗工作手册附件Mapper接口
 *
 * @author qianhe
 * @date 2024-10-09
 */
public interface BzscYsjglggzscfjMapper
{
    /**
     * 查询标准手册-油水井管理岗工作手册附件
     *
     * @param id 标准手册-油水井管理岗工作手册附件主键
     * @return 标准手册-油水井管理岗工作手册附件
     */
    public BzscYsjglggzscfj selectBzscYsjglggzscfjById(Long id);

    /**
     * 查询标准手册-油水井管理岗工作手册附件列表
     *
     * @param bzscYsjglggzscfj 标准手册-油水井管理岗工作手册附件
     * @return 标准手册-油水井管理岗工作手册附件集合
     */
    public List<BzscYsjglggzscfj> selectBzscYsjglggzscfjList(BzscYsjglggzscfj bzscYsjglggzscfj);

    /**
     * 新增标准手册-油水井管理岗工作手册附件
     *
     * @param bzscYsjglggzscfj 标准手册-油水井管理岗工作手册附件
     * @return 结果
     */
    public int insertBzscYsjglggzscfj(BzscYsjglggzscfj bzscYsjglggzscfj);

    int insertBzscYsjglggzscfjlist(List<BzscYsjglggzscfj> bzscYsjglggzscfjs);
    /**
     * 修改标准手册-油水井管理岗工作手册附件
     *
     * @param bzscYsjglggzscfj 标准手册-油水井管理岗工作手册附件
     * @return 结果
     */
    public int updateBzscYsjglggzscfj(BzscYsjglggzscfj bzscYsjglggzscfj);

    /**
     * 删除标准手册-油水井管理岗工作手册附件
     *
     * @param id 标准手册-油水井管理岗工作手册附件主键
     * @return 结果
     */
    public int deleteBzscYsjglggzscfjById(Long id);

    /**
     * 批量删除标准手册-油水井管理岗工作手册附件
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBzscYsjglggzscfjByIds(Long[] ids);
}
